@@ -89,7 +89,7 @@ class PersistentContext(object):
       if oid is None:
         # this is a new object
         if not sc:
-          transaction.savepoint() # try to associate a database
+          transaction.savepoint(True) # try to associate a database
           sc = True
       jar, oid = obj._p_jar, obj._p_oid # `AttributeError` if not persistent
       if jar is None or oid is None:
